# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"indexFlow": "00_core.ipynb",
         "queryFlow": "00_core.ipynb",
         "slugify": "01_loader.ipynb",
         "get_image_files": "01_loader.ipynb",
         "device": "03_encoder.ipynb",
         "archive_loader": "01_loader.ipynb",
         "db_loader": "01_loader.ipynb",
         "treemap_loader": "01_loader.ipynb",
         "make_dataset": "02_crafter.ipynb",
         "pil_loader": "02_crafter.ipynb",
         "DatasetImagePaths": "02_crafter.ipynb",
         "clip_transform": "02_crafter.ipynb",
         "crafter": "02_crafter.ipynb",
         "image_encoder": "03_encoder.ipynb",
         "text_encoder": "03_encoder.ipynb",
         "join_all": "04_indexer.ipynb",
         "build_treemap": "04_indexer.ipynb",
         "save_archives": "04_indexer.ipynb",
         "ranker": "05_ranker.ipynb",
         "nns_to_files": "05_ranker.ipynb",
         "top_bottom": "06_fileutils.ipynb",
         "copy_topn_images": "06_fileutils.ipynb",
         "app": "07_cli.ipynb",
         "search_folder": "07_cli.ipynb",
         "__main__": "07_cli.ipynb",
         "get_image": "08_gui.ipynb",
         "get_grid": "08_gui.ipynb",
         "update_tabs": "08_gui.ipynb",
         "page_update": "08_gui.ipynb",
         "appPage": "08_gui.ipynb"}

modules = ["core.py",
           "loader.py",
           "crafter.py",
           "encoder.py",
           "indexer.py",
           "ranker.py",
           "utils.py",
           "cli.py",
           "gui.py"]

doc_url = "https://deepfates.github.io/memery/"

git_url = "https://github.com/deepfates/memery/tree/main/"

def custom_doc_links(name): return None
